pub struct ICU4XGeneralCategoryNameToMaskMapper(PropertyValueNameToEnumMapper<GeneralCategoryGroup>);Expand description
A type capable of looking up General Category mask values from a string name.
Tuple Fields
0: PropertyValueNameToEnumMapper<GeneralCategoryGroup>Implementations
Sourceimpl ICU4XGeneralCategoryNameToMaskMapper
impl ICU4XGeneralCategoryNameToMaskMapper
Sourcepub fn get_strict(&self, name: &DiplomatStr) -> u32
pub fn get_strict(&self, name: &DiplomatStr) -> u32
Get the mask value matching the given name, using strict matching
Returns 0 if the name is unknown for this property
Sourcepub fn get_loose(&self, name: &DiplomatStr) -> u32
pub fn get_loose(&self, name: &DiplomatStr) -> u32
Get the mask value matching the given name, using loose matching
Returns 0 if the name is unknown for this property
pub fn load( provider: &ICU4XDataProvider, ) -> Result<Box<ICU4XGeneralCategoryNameToMaskMapper>, ICU4XError>